package com.muyu.common.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.annotation.Excel;
import com.muyu.common.pool.base.BaseConfig;
import com.muyu.common.core.web.domain.BaseEntity;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * 数据来源表;
 * @author : http://www.chiner.pro
 * @date : 2024-8-21
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@SuperBuilder
@EqualsAndHashCode(callSuper = true)
@TableName(value="data_sources")
public class DataSources extends BaseEntity {

    /** id */
    @TableId(type = IdType.AUTO)
    private Long id ;

    /** 数据来源类型 */
    @Excel(name = "数据来源类型")
    private String type ;


    /** 数据来源名称 */
    @Excel(name = "数据来源名称")
    private String name ;

    /** 数据来源地址ip */
    @Excel(name = "数据来源地址ip")
    private String ip ;

    /** 来源地址端口号 */
    @Excel(name = "来源地址端口号")
    private String port ;

    /** 存放数据库名称 */
    @Excel(name = "存放数据库名称")
    private String databaseName ;

    /** 数据库登录名 */
    @Excel(name = "数据库登录名")
    private String userName ;

    /** 数据库登录密码 */
    @Excel(name = "数据库登录密码")
    private String userPwd ;

    /** 参数 */
    @Excel(name = "连接参数配置")
    private String param ;

    /** 状态 1初始化 2不初始化 */
    @Excel(name = "是否初始化:1初始化,2不初始化")
    private Integer status ;

    /** 初始连接数量 */
    @Excel(name = "初始连接数量")
    private Integer initCount;

    /** 最大连接数量 */
    @Excel(name = "最大连接数量")
    private Integer maxCount;

    /** 最大等待时间 */
    @Excel(name = "最大等待时间")
    private Integer maxTime;

    /** 最大等待次数 */
    @Excel(name = "最大等待次数")
    private Integer maxFrequency;

    /** 驱动 com.mysql.cj.jdbc.Driver */
    @Excel(name = "连接驱动")
    private String driverName;

    /**
     * 获取mysql数据库连接
     * @return
     */
    public String getUrl(DataSources dataSources){

        StringBuilder urlSb = new StringBuilder(BaseConfig.MYSQLJDBCPRO);
        urlSb.append(dataSources.ip);//拼接ip
        urlSb.append(":");
        urlSb.append(dataSources.port); //拼接端口
        urlSb.append("/");
        urlSb.append(dataSources.databaseName);//拼接数据库
        urlSb.append("?");
        urlSb.append(dataSources.param);//useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
        return urlSb.toString();
    }
    /**
     * 获取mysql数据库连接
     * @return
     */
    public String getOracleUrl(DataSources dataSources){

        StringBuilder urlSb = new StringBuilder(BaseConfig.ORACLEJDBCPRO);
        urlSb.append(dataSources.ip);//拼接ip
        urlSb.append(":");
        urlSb.append(dataSources.port); //拼接端口
        urlSb.append(":");
        urlSb.append(dataSources.getParam());//PDB
        return urlSb.toString();
    }
}
