package com.muyu.datasources.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.datasources.service.DataValueService;
import com.muyu.etl.domain.DataValue;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @Author：zhangzhihao
 * @name：DataKltvController
 * @Date：2024/8/27 22:17
 * 不准抄代码，添加注释，清楚每一行代码意思
 */
@Log4j2
@RestController
@RequestMapping("dataValue")
public class DataValueController {

    @Autowired
    private DataValueService dataValueService;

    /**
     * 获取表中的值供任务模块调用
     * @param basicId
     * @param sql
     * @return
     */
    @PostMapping("/findTableValue")
    public Result<List<List<DataValue>>> findTableValue(@RequestParam("basicId") Long basicId, @RequestParam("sql") String sql){

        long l = System.currentTimeMillis();
        List<List<DataValue>> list = dataValueService.findTableValue(basicId,sql);

        long x = System.currentTimeMillis();
        long l1 = x - l;
        log.info("耗时:"+l1);
        return Result.success(list);
    }

    /**
     * 获取表中的值供前台调用
     * @param basicId
     * @param tableName
     * @return
     */
    @PostMapping("/findTableValueByTableName")
    public Result findTableValueByTableName(@RequestParam("basicId") Long basicId,@RequestParam("tableName") String tableName){
        List<DataValue> list = dataValueService.findTableValueByTableName(basicId,tableName);
        return Result.success(list);
    }


    @PostMapping("/findTableValueContributionRule")
    public Result<List<List<DataValue>>> findTableValueContributionRule(@RequestParam("basicId") Long basicId,@RequestParam("tableId") Long tableId){

        List<List<DataValue>> list = dataValueService.findTableValueContributionRule(basicId,tableId);


        return Result.success(list);
    }


    @PostMapping("/findCount")
    public Result<Long> findCount(@RequestParam("basicId") Long basicId,@RequestParam("sql") String sql){
        Long count = dataValueService.findCount(basicId,sql);
       return Result.success(count);
    }


    /**
     * 获取表中的值供任务模块调用
     * @param basicId
     * @param sql
     * @return
     */
    @PostMapping("/findTableValueToArray")
    public Result<DataValue[][]> findTableValueToArray(@RequestParam("basicId") Long basicId,
                                                       @RequestParam("sql") String sql,
                                                       @RequestParam("one") Long one,
                                                       @RequestParam("two") Integer two){

        long begin = System.currentTimeMillis();
        DataValue[][] list = dataValueService.findTableValueToArray(basicId,sql,one,two);


        long end = System.currentTimeMillis();
        long time = end - begin;
        log.info("耗时:"+time);
        return Result.success(list);
    }


    /**
     * 测试
     */
//    @PostMapping("/test")
//    public static void test() {
//        MySqlQuery mySqlQuery = new MySqlQuery();
//        String sql="select id,table_id from asset_accredit";
//        mySqlQuery.setSql(sql);
//        mySqlQuery.setDataSourceId(1L);
//        BaseQueryHandler.set(mySqlQuery);
//
//
//        MySqlDataSource mySqlDataSource = new MySqlDataSource();
//        DataValue[][] rows = mySqlDataSource.getRows();
//        System.out.println(rows);
//    }


}
