package com.muyu.datasources.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.muyu.common.core.domain.Result;

import com.muyu.common.domain.TableInfo;
import com.muyu.common.domain.resp.AssetAccreditResp;
import com.muyu.common.domain.resp.TableInfoResp;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.common.system.domain.LoginUser;
import com.muyu.common.system.domain.SysUser;
import com.muyu.datasources.service.AssetAccreditService;
import com.muyu.datasources.service.DataSourcesService;
import com.muyu.datasources.service.SysUserService;
import com.muyu.datasources.service.TableInfoService;
import jakarta.servlet.http.HttpServletRequest;
import org.jetbrains.annotations.NotNull;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.stream.Stream;


@RestController
@RequestMapping("tableInfo")
public class TableInfoController {

    @Autowired
    private TableInfoService tableInfoService;

    @Autowired
    private SysUserService sysUserService;

    @Autowired
    private AssetAccreditService assetAccreditService;

    @Autowired
    private HttpServletRequest request;




    @GetMapping("/findAsset")
    public Result findAsset(){
        List<TableInfo> list = tableInfoService.list();

        List<TableInfoResp> respList = list.stream().filter(tableInfo -> tableInfo.getParentId()==0).map(tableInfo -> {
            TableInfoResp tableInfoResp = TableInfo.toTableInfoResp(tableInfo);
            tableInfoResp.setChildren(getAssetChildren(tableInfo, list));
            return tableInfoResp;
        }).toList();

        return Result.success(respList);
    }

    /**
     * 级联查询
     * @return
     */
    @GetMapping
    public Result findByTableName() {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        SysUser sysUser = loginUser.getSysUser();
        Long userId = sysUser.getUserId();
        Long deptId = sysUser.getDeptId();
      List<AssetAccreditResp> idList = assetAccreditService.findTableIdAndBasicIdByUserId(userId);
      List<AssetAccreditResp> deptIdList = assetAccreditService.findTableIdAndBasicIdByDeptId(deptId);
        HashSet<TableInfo> set = new HashSet<>();
        for (AssetAccreditResp assetAccreditResp : idList) {
            Long basicId = assetAccreditResp.getBasicId();
            Long tableId = assetAccreditResp.getTableId();
            if (null!=basicId){
                LambdaQueryWrapper<TableInfo> wrapper = new LambdaQueryWrapper<>();
                wrapper.eq(TableInfo::getBasicId,basicId);
                List<TableInfo> tableInfoList = tableInfoService.list(wrapper);
                set.addAll(tableInfoList);
            }

            if (null!=tableId){
                TableInfo tableInfo = tableInfoService.getById(tableId);
                set.add(tableInfo);
                Long parentId = tableInfo.getParentId();
                TableInfo dataSource = tableInfoService.getById(parentId);
                set.add(dataSource);
            }
        }

        for (AssetAccreditResp assetAccreditResp : deptIdList) {
            Long basicId = assetAccreditResp.getBasicId();
            Long tableId = assetAccreditResp.getTableId();
            if (null!=basicId){
                LambdaQueryWrapper<TableInfo> wrapper = new LambdaQueryWrapper<>();
                wrapper.eq(TableInfo::getBasicId,basicId);
                List<TableInfo> tableInfoList = tableInfoService.list(wrapper);
                set.addAll(tableInfoList);
            }

            if (null!=tableId){
                TableInfo tableInfo = tableInfoService.getById(tableId);
                set.add(tableInfo);
                Long parentId = tableInfo.getParentId();
                TableInfo dataSource = tableInfoService.getById(parentId);
                set.add(dataSource);
            }
        }
        List<TableInfoResp> respList = set.stream().filter(tableInfo -> tableInfo.getParentId()==0).map(tableInfo -> {
            TableInfoResp tableInfoResp = TableInfo.toTableInfoResp(tableInfo);
            tableInfoResp.setChildren(getChildren(tableInfo, set));
            return tableInfoResp;
        }).toList();
        return Result.success(respList);
    }
    @NotNull
    private static List<TableInfoResp> getChildren(TableInfo tableInfo, HashSet<TableInfo> list) {
        return list.stream().filter(tableInfo1 -> tableInfo1.getParentId().equals(tableInfo.getId())).map(
                tableInfo2 -> TableInfo.toTableInfoResp(tableInfo2)
        ).toList();
    }


    @NotNull
    private static List<TableInfoResp> getAssetChildren(TableInfo tableInfo, List<TableInfo> list) {
        return list.stream().filter(tableInfo1 -> tableInfo1.getParentId().equals(tableInfo.getId())).map(
                tableInfo2 -> TableInfo.toTableInfoResp(tableInfo2)
        ).toList();
    }


    /**
     * 根据id查询数据
     * @param id
     * @return
     */
    @PostMapping("/findTableName")
    public Result findTableName(@RequestParam("id") Long id){
        TableInfo table = tableInfoService.getById(id);
        return Result.success(table);
    }





}
